.. mogutda documentation master file, created by
   sphinx-quickstart on Mon Jun 11 13:38:30 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to mogutda's documentation!
===================================

`mogutda` contains Python codes that demonstrate the numerical calculation
of algebraic topology in an application to topological data analysis
(TDA). Its core code is the numerical methods concerning implicial complex,
and the estimation of homology and Betti numbers.

Topological data analysis aims at studying the shapes of the data, and
draw some insights from them. A lot of machine learning algorithms deal
with distances, which are extremely useful, but they miss the
information the data may carry from their geometry.

`mogutda` runs in Python 3.8, 3.9, 3.10, 3.11, 3.12, and 3.13.

Contributors:

* Kwan-Yuet Ho (stephenhky_)
* Isla Staden (Islast_)
* Filip Cornell (Filco306_)

Contents:

.. toctree::
   :maxdepth: 2

   history
   install
   tutorial
   blogs
   refs
   links
   news

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _stephenhky:
.. _Islast: https://github.com/Islast
.. _Filco306: https://github.com/Filco306